from rocolib.api.components.Component import Component
from rocolib.api.Function import Function

#A 4-sided rectangular beam with a cutout for the battery terminals and wings for mounting

c = Component()

c.addParameter("boatwidth", 90, paramType="length")
c.addParameter("boatdepth", 70, paramType="length")

c.addParameter("batterylength", 61, paramType="length")
c.addParameter("batterywidth", 17, paramType="length")
c.addParameter("batterydepth", 9, paramType="length")

c.addParameter("numBatteries", 3, paramType="count", minValue=1, maxValue=10)

c.addSubcomponent("holder", "SimpleRectBeam", inherit=True, prefix=None)
c.addConstraint(("holder", "depth"), "batterylength")
c.addConstraint(("holder", "length"), ("numBatteries", "batterydepth"), "x[1] * x[0]")
c.addConstraint(("holder", "width"), "batterywidth")

c.addSubcomponent("larm", "Rectangle", inherit=True)
c.addConstraint(("larm", "l"), ("numBatteries", "boatwidth", "boatdepth", "batterywidth", "batterydepth"), "((0.5 * x[1] - 0.5 * (x[4] * x[0])) ** 2 + (x[2] - x[3]) ** 2) ** 0.5")
c.addConstraint(("larm", "w"), "batterylength")

c.addSubcomponent("rarm", "Rectangle", inherit=True)
c.addConstraint(("rarm", "l"), ("numBatteries","boatwidth", "boatdepth", "batterywidth", "batterydepth"), "((0.5 * x[1] - 0.5 * (x[4] * x[0])) ** 2 + (x[2] - x[3]) ** 2) ** 0.5")
c.addConstraint(("rarm", "w"), "batterylength")
#
c.addConnection(("larm", "l"), ("holder", "topedge3"), angle=-45)
c.addConnection(("rarm", "l"), ("holder", "botedge3"), angle=-45)

c.addSubcomponent("terminals", "Cutout")
c.addConstConstraint(("terminals", "dx"), 6)
c.addConstraint(("terminals", "dy"), "numBatteries", "x * 6")
c.addConnection(("holder", "face3"),
                   ("terminals", "decoration"),
                   mode="hole", offset=Function(params=("batterylength"), fnstring="(-30, 0)"))

c.inheritInterface("leftArmInterface", ("larm", "r"))
c.inheritInterface("rightArmInterface", ("rarm", "r"))

c.toLibrary("BatteryMount")
